<template>
    <div class="equity-companies">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-股权.png')" title="股权公司统计" routerPath="/platLayout/InvestmentFinancingAssets"/>
        <div class="bottom-chart">
            <div id="equity-chart"></div>
        </div>
    </div>
</template>

<script>
import * as echarts from 'echarts'
import utils from '@/utils.js'
import api from '@/api/homePage.js'
import PublicTitle from '@/components/PublicTitle/index'
export default {
    name: 'EquityCompanies', // 股权公司统计
    components: { PublicTitle },
    data() {
        return {
            colorList: [
                '#198cff',
                '#00d4ff',
                '#55edb0',
                '#ffdb2a',
                '#fdb942',
                '#ff8f57',
                '#c679e5',
            ],
            echartsData: []
        }
    },
    created() {
        this.getStock()
    },
    mounted() {
    },
    methods: {
        //字典翻译
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        getStock() {
            api.stockStatistics({}, res => {
                if (res.state) {
                    this.echartsData = res.value
                }
                this.initChat()
            })
        },
        initChat() {
            let dataList = []
            this.echartsData.forEach((e, index) => {
                dataList.push({
                    name: this.getDictName('gqgsxz', e.assetNature),
                    value: e.count,
                    itemStyle: {
                        color: this.colorList[index],
                    },
                })
            })
            let chartDom = echarts.init(document.getElementById('equity-chart'))
            let option = {
                tooltip: {
                    trigger: 'item',
                },
                legend: {
                    orient: 'vertical', // 设置为纵向排列
                    left: '50%', // 设置距离右侧的距离
                    top: '20%', // 设置居中对齐
                    itemWidth: 10, // 设置图标的宽度
                    itemHeight: 10, // 设置图标的高度
                    icon: 'circle', // 设置图标形状为圆形
                    itemGap: 20,
                    selectedMode: false
                },
                series: [
                    {
                        name: '数量',
                        type: 'pie',
                        radius: ['72%', '87%'],
                        center: ['25%', '53.4%'],
                        avoidLabelOverlap: false,
                        itemStyle: {
                            borderColor: '#fff',
                            borderWidth: 2,
                        },
                        label: {
                            show: false,
                            position: 'center',
                        },

                        emphasis: {
                            label: {
                                show: true,
                                fontSize: 24,
                                formatter: function (params) {
                                    return [
                                        '{num|' +
                                        params.value +
                                        '}' +
                                        '{unit|家}',
                                        '{label|' + params.name + '}',
                                    ].join('\n')
                                },
                                rich: {
                                    num: {
                                        fontSize: 24,
                                        color: '#000',
                                        lineHeight: 24,
                                        fontWeight: 700,
                                    },
                                    unit: {
                                        fontSize: 14,
                                        color: '#111',
                                        lineHeight: 24,
                                        padding: [0, 5],
                                    },
                                    label: {
                                        fontSize: 14,
                                        lineHeight: 24,
                                        color: '#444',
                                    },
                                },
                            },
                        },
                        labelLine: {
                            show: false,
                        },
                        data: dataList,
                    },
                    // 外圈背景
                    {
                        type: 'pie',
                        radius: ['66%', '66%'],
                        center: ['25%', '53.4%'],
                        hoverAnimation: false,
                        clockWise: false,
                        cursor: 'default',
                        itemStyle: {
                            normal: {
                                borderWidth: 2,
                                borderColor: '#eaeaea',
                            },
                        },
                        tooltip: {
                            show: false,
                        },
                        label: {
                            show: false,
                        },
                        data: [100],
                    },

                ],
            }
            chartDom.setOption(option)
            window.addEventListener('resize', () => {
                chartDom.resize()
            })
            handleChartLoop(option, chartDom);
            // 饼图自动轮播
            function handleChartLoop(option, myChart) {
                if (!myChart) {
                    return
                }
                let currentIndex = 0 // 当前高亮图形在饼图数据中的下标
                highlightPie()
                // 取消所有高亮并高亮当前图形
                function highlightPie() {
                    // 遍历饼图数据，取消所有图形的高亮效果
                    for (var idx in option.series[0].data) {
                        myChart.dispatchAction({
                            type: 'downplay',
                            seriesIndex: 0,
                            dataIndex: idx
                        })
                    }
                    // 高亮当前图形
                    myChart.dispatchAction({
                        type: 'highlight',
                        seriesIndex: 0,
                        dataIndex: currentIndex
                    })
                }
                // 用户鼠标悬浮到某一图形时，停止自动切换并高亮鼠标悬浮的图形
                myChart.on('mouseover', (params) => {
                    if (params.componentType == 'graphic') {
                        return
                    }
                    currentIndex = params.dataIndex
                    highlightPie()
                })
               
            }
        },
    },
}
</script>

<style scoped lang="scss">
.equity-companies {
    width: 100%;
    height: 100%;
    padding: 16px;
    box-sizing: border-box;
    background: #ffffff;
    box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
    border-radius: 16px 16px 16px 16px;

    .bottom-chart {
        width: 100%;
        height: calc(100% - 30px);

        #equity-chart {
            width: 100%;
            height: 100%;
        }
    }
}
</style>
